@@ -272,3 +272,19 @@ class Jira(AtlassianRestAPI):
     def delete_component(self, component_id):
         log.warning('Deleting component "{component_id}"'.format(component_id=component_id))
         return self.delete('rest/api/2/component/{component_id}'.format(component_id=component_id))
+
+    def upload_plugin(self, plugin_path):
+        """
+        Provide plugin path for upload into Jira e.g. useful for auto deploy
+        :param plugin_path:
+        :return:
+        """
+        files = {
+            'plugin': open(plugin_path, 'rb')
+        }
+        headers = {
+            'X-Atlassian-Token': 'nocheck'
+        }
+        upm_token = self.request(method='GET', path='rest/plugins/1.0/', headers=headers).headers['upm-token']
+        url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
+        return self.post(url, files=files, headers=headers)
